==> apache-pulsar-2.10.0-src.tar.gz: apache-pulsar-2.10.0-src/pulsar-client-admin-api/src/main/java/org/apache/pulsar/common/policies/data/impl/AutoSubscriptionCreationOverrideImpl.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pulsar.common.policies.data.impl;

import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.apache.pulsar.common.policies.data.AutoSubscriptionCreationOverride;

/**
 * Override of autoSubscriptionCreation settings on a namespace level.
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
public class AutoSubscriptionCreationOverrideImpl implements AutoSubscriptionCreationOverride {
    private boolean allowAutoSubscriptionCreation;

    public static AutoSubscriptionCreationOverrideImplBuilder builder() {
        return new AutoSubscriptionCreationOverrideImplBuilder();
    }

    public static class AutoSubscriptionCreationOverrideImplBuilder
            implements AutoSubscriptionCreationOverride.Builder {
        private boolean allowAutoSubscriptionCreation;

        public AutoSubscriptionCreationOverrideImplBuilder allowAutoSubscriptionCreation(
                boolean allowAutoSubscriptionCreation) {
            this.allowAutoSubscriptionCreation = allowAutoSubscriptionCreation;
            return this;
        }

        public AutoSubscriptionCreationOverrideImpl build() {
            return new AutoSubscriptionCreationOverrideImpl(allowAutoSubscriptionCreation);
        }
    }
}

==> apache-pulsar-3.0.9-src.tar.gz: apache-pulsar-3.0.9-src/pulsar-client-admin-api/src/main/java/org/apache/pulsar/common/policies/data/impl/AutoSubscriptionCreationOverrideImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.pulsar.common.policies.data.impl;

import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.apache.pulsar.common.policies.data.AutoSubscriptionCreationOverride;

/**
 * Override of autoSubscriptionCreation settings on a topic or namespace level.
 */
@Data
@AllArgsConstructor
@NoArgsConstructor
public class AutoSubscriptionCreationOverrideImpl implements AutoSubscriptionCreationOverride {
    private boolean allowAutoSubscriptionCreation;

    public static AutoSubscriptionCreationOverrideImplBuilder builder() {
        return new AutoSubscriptionCreationOverrideImplBuilder();
    }

    public static class AutoSubscriptionCreationOverrideImplBuilder
            implements AutoSubscriptionCreationOverride.Builder {
        private boolean allowAutoSubscriptionCreation;

        public AutoSubscriptionCreationOverrideImplBuilder allowAutoSubscriptionCreation(
                boolean allowAutoSubscriptionCreation) {
            this.allowAutoSubscriptionCreation = allowAutoSubscriptionCreation;
            return this;
        }

        public AutoSubscriptionCreationOverrideImpl build() {
            return new AutoSubscriptionCreationOverrideImpl(allowAutoSubscriptionCreation);
        }
    }
}
